@@ -1,4 +1,4 @@
-# Copyright 2016 - Rackspace Hosting
+# Copyright 2016 - SUSE Linux GmbH
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -13,4 +13,5 @@
 #    limitations under the License.
 
 version = '1.0.0'
-driver = 'k8s_opensuse'
+driver = 'k8s_opensuse_v1'
+container_version = '1.12.3'
