@@ -15,10 +15,10 @@
 
 import os
 
-from magnum.conductor import template_definition
+from magnum.drivers.common import template_def
 
 
-class ExampleTemplate(template_definition.BaseTemplateDefinition):
+class ExampleTemplate(template_def.BaseTemplateDefinition):
     provides = [
         {'server_type': 'vm', 'os': 'example', 'coe': 'example_coe'},
         {'server_type': 'vm', 'os': 'example2', 'coe': 'example_coe'},
@@ -28,9 +28,9 @@ class ExampleTemplate(template_definition.BaseTemplateDefinition):
         super(ExampleTemplate, self).__init__()
 
         self.add_output('server_address',
-                        bay_attr='api_address')
+                        cluster_attr='api_address')
         self.add_output('node_addresses',
-                        bay_attr='node_addresses')
+                        cluster_attr='node_addresses')
 
     def template_path(self):
         return os.path.join(os.path.dirname(__file__), 'example.yaml')
