@@ -14,7 +14,6 @@
 
 import datetime
 import operator
-import six
 
 from magnum.api.controllers import versions
 from magnum.api import versioned_method
@@ -90,8 +89,7 @@ class ControllerMetaclass(type):
                                                        cls_dict)
 
 
-@six.add_metaclass(ControllerMetaclass)
-class Controller(rest.RestController):
+class Controller(rest.RestController, metaclass=ControllerMetaclass):
     """Base Rest Controller"""
 
     def __getattribute__(self, key):
@@ -143,12 +141,12 @@ class Controller(rest.RestController):
         Example:
             @base.Controller.api_version("1.1", "1.2")
             @expose.expose(Cluster, types.uuid_or_name)
-            def get_one(self, bay_ident):
+            def get_one(self, cluster_ident):
             {...code for versions 1.1 to 1.2...}
 
             @base.Controller.api_version("1.3")
             @expose.expose(Cluster, types.uuid_or_name)
-            def get_one(self, bay_ident):
+            def get_one(self, cluster_ident):
             {...code for versions 1.3 to latest}
 
         @min_ver: string representing minimum version
