@@ -16,6 +16,7 @@ from wsme import types as wtypes
 
 from magnum.api.controllers import base
 from magnum.api.controllers.v1 import collection
+from magnum.api.controllers.v1 import types
 from magnum.api import expose
 from magnum.api import servicegroup as svcgrp_api
 from magnum.common import policy
@@ -28,10 +29,10 @@ class MagnumService(base.APIBase):
     host = wtypes.StringType(min_length=1, max_length=255)
     """Name of the host """
 
-    binary = wtypes.StringType(min_length=1, max_length=255)
+    binary = wtypes.Enum(wtypes.text, *fields.MagnumServiceBinary.ALL)
     """Name of the binary"""
 
-    state = wtypes.Enum(str, *fields.MagnumServiceState.ALL)
+    state = wtypes.Enum(wtypes.text, *fields.MagnumServiceState.ALL)
     """State of the binary"""
 
     id = wsme.wsattr(wtypes.IntegerType(minimum=1))
@@ -40,7 +41,7 @@ class MagnumService(base.APIBase):
     report_count = wsme.wsattr(wtypes.IntegerType(minimum=0))
     """The number of times the heartbeat was reported """
 
-    # disabled = wsme.wsattr(wtypes.BoolType(default=False))
+    disabled = wsme.wsattr(types.boolean, default=False)
     """If the service is 'disabled' administratively """
 
     disabled_reason = wtypes.StringType(min_length=0, max_length=255)
