@@ -13,19 +13,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import ast
 import jsonpatch
-from oslo_config import cfg
 from oslo_utils import uuidutils
 import pecan
 import wsme
 
 from magnum.common import exception
 from magnum.common import utils
+import magnum.conf
 from magnum.i18n import _
-from magnum.i18n import _LE
 from magnum import objects
 
-CONF = cfg.CONF
+CONF = magnum.conf.CONF
 
 
 JSONPATCH_EXCEPTIONS = (jsonpatch.JsonPatchException,
@@ -64,7 +64,7 @@ def validate_docker_memory(mem_str):
                                          "<number>[<unit>],"
                                          "where unit = b, k, m or g"))
     if mem < DOCKER_MINIMUM_MEMORY:
-        raise wsme.exc.ClientSideError(_("Docker Minimum memory limit"
+        raise wsme.exc.ClientSideError(_("Docker Minimum memory limit "
                                          "allowed is %d B.")
                                        % DOCKER_MINIMUM_MEMORY)
 
@@ -81,6 +81,16 @@ def apply_jsonpatch(doc, patch):
                 msg = _("The attribute %s has existed, please use "
                         "'replace' operation instead.") % p['path']
                 raise wsme.exc.ClientSideError(msg)
+
+        if (p['op'] == 'replace' and (p['path'] == '/labels' or
+                                      p['path'] == '/health_status_reason')):
+            try:
+                val = p['value']
+                dict_val = (val if isinstance(val, dict)
+                            else ast.literal_eval(val))
+                p['value'] = dict_val
+            except (SyntaxError, ValueError, AssertionError) as e:
+                raise exception.PatchError(patch=patch, reason=e)
     return jsonpatch.apply_patch(doc, patch)
 
 
@@ -120,10 +130,31 @@ def get_openstack_resource(manager, resource_ident, resource_type):
             raise exception.ResourceNotFound(name=resource_type,
                                              id=resource_ident)
         if len(matches) > 1:
-            msg = _LE("Multiple %(resource_type)s exist with same name "
-                      "%(resource_ident)s. Please use the resource id "
-                      "instead.") % {'resource_type': resource_type,
-                                     'resource_ident': resource_ident}
+            msg = ("Multiple %(resource_type)s exist with same name "
+                   "%(resource_ident)s. Please use the resource id "
+                   "instead." % {'resource_type': resource_type,
+                                 'resource_ident': resource_ident})
             raise exception.Conflict(msg)
         resource_data = matches[0]
     return resource_data
+
+
+def get_labels_diff(parent_labels, labels):
+    # Overriddent are the labels that exist in both the parent and the object
+    # but have a different value.
+    labels_overridden = {}
+    # Added are the labels that exist in the object and not in the parent.
+    labels_added = {}
+    # We consider as skipped, the labels that exist in the parent but not in
+    # the object's labels.
+    labels_skipped = {
+        k: v for k, v in parent_labels.items() if k not in labels
+    }
+    for key, value in labels.items():
+        try:
+            parent_value = parent_labels[key]
+            if parent_value != value:
+                labels_overridden[key] = parent_value
+        except KeyError:
+            labels_added[key] = value
+    return labels_overridden, labels_added, labels_skipped
