@@ -17,19 +17,22 @@
 import os
 import sys
 
-from oslo_config import cfg
+from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 from werkzeug import serving
 
 from magnum.api import app as api_app
+from magnum.common import profiler
 from magnum.common import service
+import magnum.conf
 from magnum.i18n import _
-from magnum.i18n import _LI
 from magnum.objects import base
 from magnum import version
 
-CONF = cfg.CONF
+
+CONF = magnum.conf.CONF
 LOG = logging.getLogger(__name__)
 
 
@@ -54,25 +57,34 @@ def _get_ssl_configs(use_ssl):
 def main():
     service.prepare_service(sys.argv)
 
-    gmr.TextGuruMeditation.setup_autorun(version)
+    gmr_opts.set_defaults(CONF)
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
 
     # Enable object backporting via the conductor
     base.MagnumObject.indirection_api = base.MagnumObjectIndirectionAPI()
 
     app = api_app.load_app()
 
+    # Setup OSprofiler for WSGI service
+    profiler.setup('magnum-api', CONF.host)
+
     # SSL configuration
     use_ssl = CONF.api.enabled_ssl
 
     # Create the WSGI server and start it
-    host, port = cfg.CONF.api.host, cfg.CONF.api.port
+    host, port = CONF.api.host, CONF.api.port
 
-    LOG.info(_LI('Starting server in PID %s'), os.getpid())
+    LOG.info('Starting server in PID %s', os.getpid())
     LOG.debug("Configuration:")
-    cfg.CONF.log_opt_values(LOG, logging.DEBUG)
+    CONF.log_opt_values(LOG, logging.DEBUG)
 
-    LOG.info(_LI('Serving on %(proto)s://%(host)s:%(port)s'),
+    LOG.info('Serving on %(proto)s://%(host)s:%(port)s',
              dict(proto="https" if use_ssl else "http", host=host, port=port))
 
-    serving.run_simple(host, port, app,
+    workers = CONF.api.workers
+    if not workers:
+        workers = processutils.get_worker_count()
+    LOG.info('Server will handle each request in a new process up to'
+             ' %s concurrent processes', workers)
+    serving.run_simple(host, port, app, processes=workers,
                        ssl_context=_get_ssl_configs(use_ssl))
