@@ -13,120 +13,20 @@
 # under the License.
 
 from barbicanclient import client as barbicanclient
+from cinderclient.v3 import client as cinder_client
 from glanceclient import client as glanceclient
 from heatclient import client as heatclient
 from keystoneauth1.exceptions import catalog
 from neutronclient.v2_0 import client as neutronclient
 from novaclient import client as novaclient
-from oslo_config import cfg
+from octaviaclient.api.v2 import octavia
 from oslo_log import log as logging
 
 from magnum.common import exception
 from magnum.common import keystone
-from magnum.i18n import _
-from magnum.i18n import _LW
-
-common_security_opts = [
-    cfg.StrOpt('ca_file',
-               help=_('Optional CA cert file to use in SSL connections.')),
-    cfg.StrOpt('cert_file',
-               help=_('Optional PEM-formatted certificate chain file.')),
-    cfg.StrOpt('key_file',
-               help=_('Optional PEM-formatted file that contains the '
-                      'private key.')),
-    cfg.BoolOpt('insecure',
-                default=False,
-                help=_("If set, then the server's certificate will not "
-                       "be verified."))]
-
-magnum_client_opts = [
-    cfg.StrOpt('region_name',
-               help=_('Region in Identity service catalog to use for '
-                      'communication with the OpenStack service.')),
-    cfg.StrOpt('endpoint_type',
-               default='publicURL',
-               help=_(
-                   'Type of endpoint in Identity service catalog to use '
-                   'for communication with the OpenStack service.'))]
-
-heat_client_opts = [
-    cfg.StrOpt('region_name',
-               help=_('Region in Identity service catalog to use for '
-                      'communication with the OpenStack service.')),
-    cfg.StrOpt('endpoint_type',
-               default='publicURL',
-               help=_(
-                   'Type of endpoint in Identity service catalog to use '
-                   'for communication with the OpenStack service.')),
-    cfg.StrOpt('api_version',
-               default='1',
-               help=_('Version of Heat API to use in heatclient.'))]
-
-glance_client_opts = [
-    cfg.StrOpt('region_name',
-               help=_('Region in Identity service catalog to use for '
-                      'communication with the OpenStack service.')),
-    cfg.StrOpt('endpoint_type',
-               default='publicURL',
-               help=_(
-                   'Type of endpoint in Identity service catalog to use '
-                   'for communication with the OpenStack service.')),
-    cfg.StrOpt('api_version',
-               default='2',
-               help=_('Version of Glance API to use in glanceclient.'))]
-
-barbican_client_opts = [
-    cfg.StrOpt('region_name',
-               help=_('Region in Identity service catalog to use for '
-                      'communication with the OpenStack service.')),
-    cfg.StrOpt('endpoint_type',
-               default='publicURL',
-               help=_(
-                   'Type of endpoint in Identity service catalog to use '
-                   'for communication with the OpenStack service.'))]
-
-nova_client_opts = [
-    cfg.StrOpt('region_name',
-               help=_('Region in Identity service catalog to use for '
-                      'communication with the OpenStack service.')),
-    cfg.StrOpt('endpoint_type',
-               default='publicURL',
-               help=_(
-                   'Type of endpoint in Identity service catalog to use '
-                   'for communication with the OpenStack service.')),
-    cfg.StrOpt('api_version',
-               default='2',
-               help=_('Version of Nova API to use in novaclient.'))]
-
-neutron_client_opts = [
-    cfg.StrOpt('region_name',
-               help=_('Region in Identity service catalog to use for '
-                      'communication with the OpenStack service.')),
-    cfg.StrOpt('endpoint_type',
-               default='publicURL',
-               help=_(
-                   'Type of endpoint in Identity service catalog to use '
-                   'for communication with the OpenStack service.'))]
-
-cinder_client_opts = [
-    cfg.StrOpt('region_name',
-               help=_('Region in Identity service catalog to use for '
-                      'communication with the OpenStack service.'))]
-
-
-cfg.CONF.register_opts(magnum_client_opts, group='magnum_client')
-cfg.CONF.register_opts(heat_client_opts, group='heat_client')
-cfg.CONF.register_opts(glance_client_opts, group='glance_client')
-cfg.CONF.register_opts(barbican_client_opts, group='barbican_client')
-cfg.CONF.register_opts(nova_client_opts, group='nova_client')
-cfg.CONF.register_opts(neutron_client_opts, group='neutron_client')
-cfg.CONF.register_opts(cinder_client_opts, group='cinder_client')
-
-cfg.CONF.register_opts(common_security_opts, group='heat_client')
-cfg.CONF.register_opts(common_security_opts, group='glance_client')
-cfg.CONF.register_opts(common_security_opts, group='nova_client')
-cfg.CONF.register_opts(common_security_opts, group='neutron_client')
+import magnum.conf
 
+CONF = magnum.conf.CONF
 LOG = logging.getLogger(__name__)
 
 
@@ -141,6 +41,8 @@ class OpenStackClients(object):
         self._barbican = None
         self._nova = None
         self._neutron = None
+        self._octavia = None
+        self._cinder = None
 
     def url_for(self, **kwargs):
         return self.keystone().session.get_endpoint(**kwargs)
@@ -156,8 +58,8 @@ class OpenStackClients(object):
             url = self.url_for(service_type='container',
                                interface=endpoint_type,
                                region_name=region_name)
-            LOG.warning(_LW('Service type "container" is deprecated and will '
-                            'be removed in a subsequent release'))
+            LOG.warning('Service type "container" is deprecated and will '
+                        'be removed in a subsequent release')
             return url
 
     def cinder_region_name(self):
@@ -180,7 +82,22 @@ class OpenStackClients(object):
         return self._keystone
 
     def _get_client_option(self, client, option):
-        return getattr(getattr(cfg.CONF, '%s_client' % client), option)
+        return getattr(getattr(CONF, '%s_client' % client), option)
+
+    @exception.wrap_keystone_exception
+    def octavia(self):
+        if self._octavia:
+            return self._octavia
+
+        region_name = self._get_client_option('octavia', 'region_name')
+        endpoint_type = self._get_client_option('octavia', 'endpoint_type')
+        endpoint = self.url_for(service_type='load-balancer',
+                                interface=endpoint_type,
+                                region_name=region_name)
+        session = self.keystone().session
+        return octavia.OctaviaAPI(session=session,
+                                  service_type='load-balancer',
+                                  endpoint=endpoint)
 
     @exception.wrap_keystone_exception
     def heat(self):
@@ -266,9 +183,10 @@ class OpenStackClients(object):
             'insecure': self._get_client_option('nova', 'insecure')
         }
 
+        session = self.keystone().session
         self._nova = novaclient.Client(novaclient_version,
-                                       auth_token=self.auth_token, **args)
-        self._nova.client.management_url = endpoint
+                                       session=session,
+                                       endpoint_override=endpoint, **args)
         return self._nova
 
     @exception.wrap_keystone_exception
@@ -291,3 +209,24 @@ class OpenStackClients(object):
         }
         self._neutron = neutronclient.Client(**args)
         return self._neutron
+
+    @exception.wrap_keystone_exception
+    def cinder(self):
+        if self._cinder:
+            return self._cinder
+        endpoint_type = self._get_client_option('cinder', 'endpoint_type')
+        region_name = self._get_client_option('cinder', 'region_name')
+        cinderclient_version = self._get_client_option('cinder', 'api_version')
+        endpoint = self.url_for(service_type='block-storage',
+                                interface=endpoint_type,
+                                region_name=region_name)
+        args = {
+            'cacert': self._get_client_option('cinder', 'ca_file'),
+            'insecure': self._get_client_option('cinder', 'insecure')
+        }
+
+        session = self.keystone().session
+        self._cinder = cinder_client.Client(cinderclient_version,
+                                            session=session,
+                                            endpoint_override=endpoint, **args)
+        return self._cinder
