@@ -211,7 +211,7 @@ class KeystoneClientV3(object):
                 project=trustor_project_id,
                 trustee_user=trustee_user,
                 impersonation=True,
-                delegation_depth=0,
+                allow_redelegation=False,
                 role_names=roles)
         except Exception:
             LOG.exception('Failed to create trust')
@@ -263,14 +263,16 @@ class KeystoneClientV3(object):
                                                 domain_id=domain_id)
         return user
 
-    def delete_trustee(self, trustee_id):
+    def delete_trustee(self, trustee_user_id):
+        if trustee_user_id is None:
+            return
         try:
-            self.domain_admin_client.users.delete(trustee_id)
+            self.domain_admin_client.users.delete(trustee_user_id)
         except kc_exception.NotFound:
             pass
         except Exception:
             LOG.exception('Failed to delete trustee')
-            raise exception.TrusteeDeleteFailed(trustee_id=trustee_id)
+            raise exception.TrusteeDeleteFailed(trustee_id=trustee_user_id)
 
     def get_validate_region_name(self, region_name):
         if region_name is None:
