@@ -12,31 +12,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
 from oslo_log import log as logging
 
 from magnum.common import config
-from magnum.i18n import _
+import magnum.conf
 
-
-service_opts = [
-    cfg.StrOpt('host',
-               default=None,
-               help=_('Name of this node. This can be an opaque identifier. '
-                      'It is not necessarily a hostname, FQDN, or IP address. '
-                      'However, the node name must be valid within '
-                      'an AMQP key, and if using ZeroMQ, a valid '
-                      'hostname, FQDN, or IP address.')),
-]
-
-cfg.CONF.register_opts(service_opts)
+CONF = magnum.conf.CONF
 
 
 def prepare_service(argv=None):
     if argv is None:
         argv = []
-    logging.register_options(cfg.CONF)
+    logging.register_options(CONF)
     config.parse_args(argv)
     config.set_config_defaults()
 
-    logging.setup(cfg.CONF, 'magnum')
+    logging.setup(CONF, 'magnum')
