@@ -23,10 +23,13 @@ Create Date: 2015-02-26 05:02:34.260099
 revision = '35cff7c86221'
 down_revision = '3a938526b35d'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+
+from sqlalchemy.types import String  # noqa: E402
+
+import sqlalchemy as sa  # noqa: E402
 
 
 def upgrade():
-    op.add_column('baymodel', sa.Column('fixed_network', sa.String(length=255),
-                  nullable=True))
+    op.add_column('baymodel', sa.Column('fixed_network',
+                  String(255), nullable=True))
