@@ -22,9 +22,8 @@ data:
         address = ":80"
       [entryPoints.https]
         address = ":443"
-      [entryPoints.metrics]
-        address = ":8082"
         [entryPoints.https.tls]
+          minVersion = "VersionTLS12"
           cipherSuites = [
             "TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305",
             "TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305",
@@ -44,6 +43,8 @@ data:
             "TLS_RSA_WITH_AES_256_CBC_SHA",
             "TLS_RSA_WITH_AES_128_CBC_SHA"
           ]
+      [entryPoints.metrics]
+        address = ":8082"
 ---
 kind: DaemonSet
 apiVersion: apps/v1
@@ -69,6 +70,10 @@ spec:
       containers:
       - image: ${CONTAINER_INFRA_PREFIX:-docker.io/}traefik:${TRAEFIK_INGRESS_CONTROLLER_TAG}
         name: ingress-traefik-backend
+        resources:
+          requests:
+            cpu: 100m
+            memory: 50Mi
         ports:
         - name: http
           containerPort: 80
@@ -123,7 +128,7 @@ spec:
       targetPort: metrics
 ---
 kind: ClusterRole
-apiVersion: rbac.authorization.k8s.io/v1beta1
+apiVersion: rbac.authorization.k8s.io/v1
 metadata:
   name: ingress-traefik
 rules:
@@ -147,7 +152,7 @@ rules:
       - watch
 ---
 kind: ClusterRoleBinding
-apiVersion: rbac.authorization.k8s.io/v1beta1
+apiVersion: rbac.authorization.k8s.io/v1
 metadata:
   name: ingress-traefik
 roleRef:
@@ -169,7 +174,7 @@ EOF
 
 writeFile $INGRESS_TRAEFIK_MANIFEST "$INGRESS_TRAEFIK_MANIFEST_CONTENT"
 
-until  [ "ok" = "$(curl --silent http://127.0.0.1:8080/healthz)" ]
+until  [ "ok" = "$(kubectl get --raw='/healthz')" ]
 do
     echo "Waiting for Kubernetes API..."
     sleep 5
