@@ -56,12 +56,15 @@ HTTP_PROXY="$HTTP_PROXY"
 HTTPS_PROXY="$HTTPS_PROXY"
 NO_PROXY="$NO_PROXY"
 WAIT_CURL="$WAIT_CURL"
+HYPERKUBE_PREFIX="$HYPERKUBE_PREFIX"
 KUBE_TAG="$KUBE_TAG"
 FLANNEL_NETWORK_CIDR="$FLANNEL_NETWORK_CIDR"
 PODS_NETWORK_CIDR="$PODS_NETWORK_CIDR"
 KUBE_VERSION="$KUBE_VERSION"
 TRUSTEE_USER_ID="$TRUSTEE_USER_ID"
+TRUSTEE_USERNAME="$TRUSTEE_USERNAME"
 TRUSTEE_PASSWORD="$TRUSTEE_PASSWORD"
+TRUSTEE_DOMAIN_ID="$TRUSTEE_DOMAIN_ID"
 TRUST_ID="$TRUST_ID"
 CLOUD_PROVIDER_ENABLED="$CLOUD_PROVIDER_ENABLED"
 INSECURE_REGISTRY_URL="$INSECURE_REGISTRY_URL"
@@ -71,6 +74,9 @@ DNS_CLUSTER_DOMAIN="$DNS_CLUSTER_DOMAIN"
 KUBELET_OPTIONS="$KUBELET_OPTIONS"
 KUBEPROXY_OPTIONS="$KUBEPROXY_OPTIONS"
 OCTAVIA_ENABLED="$OCTAVIA_ENABLED"
+OCTAVIA_PROVIDER="$OCTAVIA_PROVIDER"
+OCTAVIA_LB_ALGORITHM=$OCTAVIA_LB_ALGORITHM
+OCTAVIA_LB_HEALTHCHECK=$OCTAVIA_LB_HEALTHCHECK
 HEAT_CONTAINER_AGENT_TAG="$HEAT_CONTAINER_AGENT_TAG"
 AUTO_HEALING_ENABLED="$AUTO_HEALING_ENABLED"
 AUTO_HEALING_CONTROLLER="$AUTO_HEALING_CONTROLLER"
