@@ -3,7 +3,6 @@ set +x
 set -x
 
 $ssh_cmd mkdir -p /etc/kubernetes/
-$ssh_cmd cp /etc/pki/tls/certs/ca-bundle.crt /etc/kubernetes/ca-bundle.crt
 
 if [ -n "${TRUST_ID}" ]; then
     KUBE_OS_CLOUD_CONFIG=/etc/kubernetes/cloud-config
@@ -21,7 +20,9 @@ ca-file=/etc/kubernetes/ca-bundle.crt
 use-octavia=$OCTAVIA_ENABLED
 subnet-id=$CLUSTER_SUBNET
 floating-network-id=$EXTERNAL_NETWORK_ID
-create-monitor=yes
+lb-provider=$OCTAVIA_PROVIDER
+lb-method=$OCTAVIA_LB_ALGORITHM
+create-monitor=$OCTAVIA_LB_HEALTHCHECK
 monitor-delay=1m
 monitor-timeout=30s
 monitor-max-retries=3
