@@ -15,17 +15,30 @@
 from magnum.objects import certificate
 from magnum.objects import cluster
 from magnum.objects import cluster_template
+from magnum.objects import federation
 from magnum.objects import magnum_service
+from magnum.objects import nodegroup
+from magnum.objects import quota
+from magnum.objects import stats
 from magnum.objects import x509keypair
 
 
 Cluster = cluster.Cluster
 ClusterTemplate = cluster_template.ClusterTemplate
 MagnumService = magnum_service.MagnumService
+Quota = quota.Quota
 X509KeyPair = x509keypair.X509KeyPair
 Certificate = certificate.Certificate
+Stats = stats.Stats
+Federation = federation.Federation
+NodeGroup = nodegroup.NodeGroup
 __all__ = (Cluster,
            ClusterTemplate,
            MagnumService,
            X509KeyPair,
-           Certificate)
+           Certificate,
+           Stats,
+           Quota,
+           Federation,
+           NodeGroup
+           )
