@@ -269,6 +269,10 @@ class TestPatch(api_base.FunctionalTest):
             labels={'key1': 'val1', 'key2': 'val2'},
             hidden=False
         )
+        p = mock.patch.object(
+            attr_validator, 'validate_flavor_root_volume_size')
+        self.mock_valid_flavor_disk = p.start()
+        self.addCleanup(p.stop)
 
     def test_update_not_found(self):
         uuid = uuidutils.generate_uuid()
@@ -482,6 +486,19 @@ class TestPatch(api_base.FunctionalTest):
         self.assertEqual(400, response.status_code)
         self.assertTrue(response.json['errors'])
 
+    def test_replace_cluster_template_with_invalid_flavor(self):
+        self.mock_valid_flavor_disk.side_effect = \
+            exception.FlavorZeroRootVolumeNotSupported()
+        response = self.patch_json('/clustertemplates/%s' %
+                                   self.cluster_template.uuid,
+                                   [{'path': '/flavor_id', 'value': 'aaa',
+                                     'op': 'replace'}],
+                                   expect_errors=True)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(400, response.status_code)
+        self.assertTrue(self.mock_valid_flavor_disk.called)
+        self.assertTrue(response.json['errors'])
+
     def test_replace_cluster_template_with_no_exist_keypair_id(self):
         self.mock_valid_os_res.side_effect = exception.KeyPairNotFound("aaa")
         response = self.patch_json('/clustertemplates/%s' %
@@ -632,6 +649,10 @@ class TestPost(api_base.FunctionalTest):
         p = mock.patch.object(attr_validator, 'validate_os_resources')
         self.mock_valid_os_res = p.start()
         self.addCleanup(p.stop)
+        p = mock.patch.object(
+            attr_validator, 'validate_flavor_root_volume_size')
+        self.mock_valid_flavor_disk = p.start()
+        self.addCleanup(p.stop)
 
     @mock.patch('magnum.api.attr_validator.validate_image')
     @mock.patch('oslo_utils.timeutils.utcnow')
@@ -762,6 +783,21 @@ class TestPost(api_base.FunctionalTest):
             cc_mock.assert_called_once_with(mock.ANY)
             self.assertNotIn('id', cc_mock.call_args[0][0])
 
+    @mock.patch('magnum.api.attr_validator.validate_image')
+    def test_create_cluster_template_without_labels(self, mock_image_data):
+        with mock.patch.object(
+                self.dbapi, 'create_cluster_template',
+                wraps=self.dbapi.create_cluster_template) as cc_mock:
+            mock_image_data.return_value = {'name': 'mock_name',
+                                            'os_distro': 'fedora-coreos'}
+            bdict = apiutils.cluster_template_post_data()
+            bdict.pop("labels")
+            response = self.post_json('/clustertemplates', bdict)
+            self.assertEqual(dict(),
+                             response.json['labels'])
+            cc_mock.assert_called_once_with(mock.ANY)
+            self.assertNotIn('id', cc_mock.call_args[0][0])
+
     @mock.patch('magnum.api.attr_validator.validate_image')
     def test_create_cluster_template_with_docker_volume_size(self,
                                                              mock_image_data):
@@ -1099,6 +1135,19 @@ class TestPost(api_base.FunctionalTest):
         self.assertEqual(bdict['master_flavor_id'],
                          response.json['master_flavor_id'])
 
+    @mock.patch('magnum.api.attr_validator.validate_image')
+    def test_create_cluster_template_without_flavor(self,
+                                                    mock_image_data):
+        mock_image_data.return_value = {'name': 'mock_name',
+                                        'os_distro': 'fedora-coreos'}
+        bdict = apiutils.cluster_template_post_data()
+        del bdict['flavor_id']
+        del bdict['master_flavor_id']
+        response = self.post_json('/clustertemplates', bdict)
+        self.assertEqual(201, response.status_int)
+        self.assertIsNone(response.json['flavor_id'])
+        self.assertIsNone(response.json['master_flavor_id'])
+
     @mock.patch('magnum.api.attr_validator.validate_image')
     def test_create_cluster_template_with_no_exist_flavor(self,
                                                           mock_image_data):
@@ -1110,6 +1159,21 @@ class TestPost(api_base.FunctionalTest):
                                   expect_errors=True)
         self.assertEqual(400, response.status_int)
 
+    @mock.patch('magnum.api.attr_validator.validate_image')
+    def test_create_cluster_template_with_invalid_flavor(
+        self,
+        mock_image_data
+    ):
+        self.mock_valid_flavor_disk.side_effect = \
+            exception.FlavorZeroRootVolumeNotSupported()
+        mock_image_data.return_value = {'name': 'mock_name',
+                                        'os_distro': 'fedora-coreos'}
+        bdict = apiutils.cluster_template_post_data()
+        response = self.post_json('/clustertemplates', bdict,
+                                  expect_errors=True)
+        self.assertTrue(self.mock_valid_flavor_disk.called)
+        self.assertEqual(400, response.status_int)
+
     @mock.patch('magnum.api.attr_validator.validate_image')
     def test_create_cluster_template_with_external_network(self,
                                                            mock_image_data):
