@@ -16,7 +16,6 @@ from unittest import mock
 
 from oslo_utils import uuidutils
 
-import six
 import webtest
 import wsme
 from wsme import types as wtypes
@@ -192,7 +191,7 @@ class TestJsonPatchType(base.FunctionalTest):
 class TestMultiType(base.FunctionalTest):
 
     def test_valid_values(self):
-        vt = types.MultiType(wsme.types.text, six.integer_types)
+        vt = types.MultiType(wsme.types.text, int)
         value = vt.validate("hello")
         self.assertEqual("hello", value)
         value = vt.validate(10)
@@ -205,18 +204,18 @@ class TestMultiType(base.FunctionalTest):
         value = vt.validate(uuid)
         self.assertEqual(uuid, value)
 
-        vt = types.MultiType(types.UuidType, six.integer_types)
+        vt = types.MultiType(types.UuidType, int)
         value = vt.validate(10)
         self.assertEqual(10, value)
         value = vt.validate(uuid)
         self.assertEqual(uuid, value)
 
     def test_invalid_values(self):
-        vt = types.MultiType(wsme.types.text, six.integer_types)
+        vt = types.MultiType(wsme.types.text, int)
         self.assertRaises(ValueError, vt.validate, 0.10)
         self.assertRaises(ValueError, vt.validate, object())
 
-        vt = types.MultiType(types.UuidType, six.integer_types)
+        vt = types.MultiType(types.UuidType, int)
         self.assertRaises(ValueError, vt.validate, 'abc')
         self.assertRaises(ValueError, vt.validate, 0.10)
 
