@@ -12,16 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from unittest import mock
 import uuid
 
-from barbicanclient import client as barbican_client
-from barbicanclient import containers
-from barbicanclient import secrets
-import mock
-from mock import patch
+from barbicanclient.v1 import client as barbican_client
+from barbicanclient.v1 import containers
+from barbicanclient.v1 import secrets
+from unittest.mock import patch
 
 from magnum.common.cert_manager import barbican_cert_manager as bcm
 from magnum.common.cert_manager import cert_manager
+from magnum.common import exception as magnum_exc
 from magnum.tests import base
 
 
@@ -175,12 +176,13 @@ class TestBarbicanManager(base.BaseTestCase):
             self.secret4
         ]
         bc.secrets.create.side_effect = test_secrets
-        self.empty_container.store.side_effect = ValueError()
+        self.empty_container.store.side_effect =\
+            magnum_exc.CertificateStorageException
         mock_barbican.return_value = bc
 
         # Attempt to store a cert
         self.assertRaises(
-            ValueError,
+            magnum_exc.CertificateStorageException,
             bcm.CertManager.store_cert,
             certificate=self.certificate,
             private_key=self.private_key,
